.. currentmodule:: attr

.. :changelog:

Changelog
=========

Versions are year-based with a strict :doc:`backwards-compatibility policy <backward-compatibility>`.
The third digit is only for regressions.


15.1.0 (2015-04-15)
-------------------


Changes:
^^^^^^^^

- none yet


15.0.0 (2015-04-15)
-------------------


Changes:
^^^^^^^^

- Initial release.
